from .base import Base


class Snapshots(Base):
    def __init__(self, client):
        super(Snapshots, self).__init__(client)
        self.client = client

    def create_new_snapshot(
        self,
        dashboard=None,
        name=None,
        expires=None,
        external=None,
        key=None,
        delete_key=None,
    ):
        """

        :param dashboard:  Required. The complete dashboard model.
        :param name: Optional. snapshot name
        :param expires: Optional. When the snapshot should expire in seconds. 3600 is 1 hour, 86400 is 1 day. Default is never to expire.
        :param external: Optional. Save the snapshot on an external server rather than locally. Default is false.
        :param key: Optional. Define the unique key. Required if external is true.
        :param deleteKey: Optional. Unique key used to delete the snapshot. It is different from the key so that only the creator can delete the snapshot. Required if external is true.
        :return:
        """

        path = "/snapshots"
        post_json = {"dashboard": dashboard}
        if name:
            post_json["name"] = name
        if expires:
            post_json["expires"] = expires
        if external:
            post_json["external"] = external
        if key:
            post_json["key"] = key
        if delete_key:
            post_json["deleteKey"] = delete_key

        r = self.client.POST(path, json=post_json)
        return r

    def get_dashboard_snapshots(self):
        """

        :return:
        """
        path = "/dashboard/snapshots"
        r = self.client.GET(path)
        return r

    def get_snapshot_by_key(self, key):
        """

        :param key:
        :return:
        """
        path = "/snapshots/%s" % key
        r = self.client.GET(path)
        return r

    def delete_snapshot_by_key(self, snapshot_id=None):
        """

        :param snapshot_id:
        :return:
        """
        path = "/snapshots/{}".format(snapshot_id)
        r = self.client.DELETE(path)

        return r

    def delete_snapshot_by_delete_key(self, snapshot_delete_key=None):
        """

        :param snapshot_delete_key:
        :return:
        """
        path = "/snapshots-delete/{}".format(snapshot_delete_key)
        r = self.client.GET(path)

        return r



from .base import Base


class Notifications(Base):
    def __init__(self, client):
        super(Notifications, self).__init__(client)
        self.client = client

    def get_channels(self):
        """
        https://grafana.com/docs/grafana/latest/http_api/alerting_notification_channels/#get-all-notification-channels

        :return: all notification channels that the authenticated user has permission to view
        """
        get_channels_path = "/alert-notifications"
        return self.client.GET(get_channels_path)

    def lookup_channels(self):
        """
        https://grafana.com/docs/grafana/latest/http_api/alerting_notification_channels/#get-all-notification-channels-lookup

        :return: all notification channels, but with less detailed information
        """
        lookup_channels_path = "/alert-notifications/lookup"
        return self.client.GET(lookup_channels_path)

    def get_channel_by_uid(self, channel_uid):
        """
        https://grafana.com/docs/grafana/latest/http_api/alerting_notification_channels/#get-notification-channel-by-uid

        :param channel_uid: notification channel uid
        :return: notification channel for the given channel uid
        """
        get_channel_by_uid_path = "/alert-notifications/uid/%s" % channel_uid
        return self.client.GET(get_channel_by_uid_path)

    def get_channel_by_id(self, channel_id):
        """
        https://grafana.com/docs/grafana/latest/http_api/alerting_notification_channels/#get-notification-channel-by-id

        :param: notification channel id
        :return: notification channel for the given channel id
        """
        get_channel_by_id_path = "/alert-notifications/%s" % channel_id
        return self.client.GET(get_channel_by_id_path)

    def create_channel(self, channel):
        """
        https://grafana.com/docs/grafana/latest/http_api/alerting_notification_channels/#create-notification-channel

        :param: channel to be created
        :return: created channel
        """
        create_channel_path = "/alert-notifications"
        return self.client.POST(create_channel_path, json=channel)

    def update_channel_by_uid(self, uid, channel):
        """
        https://grafana.com/docs/grafana/latest/http_api/alerting_notification_channels/#update-notification-channel-by-uid

        :param uid: notification channel uid
        :param channel: updated version of channel
        :return: updated version of channel
        """
        update_channel_by_uid_path = "/alert-notifications/uid/%s" % uid
        return self.client.PUT(update_channel_by_uid_path, json=channel)

    def update_channel_by_id(self, id, channel):
        """
        https://grafana.com/docs/grafana/latest/http_api/alerting_notification_channels/#update-notification-channel-by-id

        :param id: notification channel id
        :param channel: updated version of channel
        :return: updated version of channel
        """
        update_channel_by_id_path = "/alert-notifications/%s" % id
        return self.client.PUT(update_channel_by_id_path, json=channel)

    def delete_notification_by_uid(self, notification_uid):
        """
        https://grafana.com/docs/grafana/latest/http_api/alerting_notification_channels/#delete-alert-notification-by-uid

        :param notification_uid: notification channel uid
        :return: result of deletion
        """
        delete_notification_by_uid_path = "/alert-notifications/uid/%s" % notification_uid
        return self.client.DELETE(delete_notification_by_uid_path)

    def delete_notification_by_id(self, notification_id):
        """
        https://grafana.com/docs/grafana/latest/http_api/alerting_notification_channels/#delete-alert-notification-by-uid

        :param notification_id: notification channel id
        :return: result of deletion
        """
        delete_notification_by_id_path = "/alert-notifications/%s" % notification_id
        return self.client.DELETE(delete_notification_by_id_path)



from .base import Base


class Teams(Base):
    def __init__(self, client):
        super(Teams, self).__init__(client)
        self.client = client

    def search_teams(self, query=None, page=None, perpage=None):
        """

        :return:
        """
        list_of_teams = []
        search_teams_path = "/teams/search"
        params = []

        if query:
            params.append("query=%s" % query)

        if page:
            iterate = False
            params.append("page=%s" % page)
        else:
            iterate = True
            params.append("page=%s")
            page = 1

        if perpage:
            params.append("perpage=%s" % perpage)

        search_teams_path += "?"
        search_teams_path += "&".join(params)

        if iterate:
            while True:
                teams_on_page = self.client.GET(search_teams_path % page)
                list_of_teams += teams_on_page["teams"]
                if len(list_of_teams) == teams_on_page["totalCount"]:
                    break
                page += 1
        else:
            teams_on_page = self.client.GET(search_teams_path)
            list_of_teams += teams_on_page["teams"]

        return list_of_teams

    def get_team_by_name(self, team_name):
        """

        :param team_name:
        :return:
        """
        search_teams_path = "/teams/search"

        search_teams_path += "?name=%s" % team_name

        teams_on_page = self.client.GET(search_teams_path)
        return teams_on_page["teams"]

    def get_team(self, team_id):
        """

        :param team_id:
        :return:
        """
        get_team_path = "/teams/%s" % team_id
        r = self.client.GET(get_team_path)
        return r

    def add_team(self, team):
        """

        :param team:
        :return:
        """
        add_team_path = "/teams"
        r = self.client.POST(add_team_path, json=team)
        return r

    def update_team(self, team_id, team):
        """

        :param team_id:
        :param team:
        :return:
        """
        update_team_path = "/teams/%s" % team_id
        r = self.client.PUT(update_team_path, json=team)
        return r

    def delete_team(self, team_id):
        """

        :param team_id:
        :return:
        """
        delete_team_path = "/teams/%s" % team_id
        r = self.client.DELETE(delete_team_path)
        return True

    def get_team_members(self, team_id):
        """

        :param team_id:
        :return:
        """
        get_team_members_path = "/teams/%s/members" % team_id
        r = self.client.GET(get_team_members_path)
        return r

    def add_team_member(self, team_id, user_id):
        """

        :param team_id:
        :param user_id:
        :return:
        """
        add_team_member_path = "/teams/%s/members" % team_id
        payload = {"userId": user_id}
        r = self.client.POST(add_team_member_path, json=payload)
        return r

    def remove_team_member(self, team_id, user_id):
        """

        :param team_id:
        :param user_id:
        :return:
        """
        remove_team_member_path = "/teams/%s/members/%s" % (team_id, user_id)
        r = self.client.DELETE(remove_team_member_path)
        return r

    def get_team_preferences(self, team_id):
        """

        :param team_id:
        :return:
        """
        get_team_preferences_path = "/teams/%s/preferences" % team_id
        r = self.client.GET(get_team_preferences_path)
        return r

    def update_team_preferences(self, team_id, preferences):
        """

        :param team_id:
        :param preferences:
        :return:
        """
        update_team_preferences_path = "/teams/%s/preferences" % team_id
        r = self.client.PUT(update_team_preferences_path, json=preferences)
        return r



from .base import Base


class Annotations(Base):
    def __init__(self, client):
        super(Annotations, self).__init__(client)
        self.client = client

    def get_annotation(
        self,
        time_from=None,
        time_to=None,
        alert_id=None,
        dashboard_id=None,
        panel_id=None,
        user_id=None,
        ann_type=None,
        tags=None,
        limit=None,
    ):

        """
        https://grafana.com/docs/grafana/latest/http_api/annotations/#find-annotations

        :param time_from:
        :param time_to:
        :param alert_id:
        :param dashboard_id:
        :param panel_id:
        :param user_id:
        :param ann_type: Annotation type. On of alert|annotation
        :param tags:
        :param limit:
        :return:
        """
        list_annotations_path = "/annotations"
        params = []

        if time_from:
            params.append("from=%s" % time_from)

        if time_to:
            params.append("to=%s" % time_to)

        if alert_id:
            params.append("alertId=%s" % alert_id)

        if dashboard_id:
            params.append("dashboardID=%s" % dashboard_id)

        if panel_id:
            params.append("panelId=%s" % panel_id)

        if user_id:
            params.append("userId=%s", user_id)

        if ann_type:
            params.append("type=%s", ann_type)

        if tags:
            for tag in tags:
                params.append("tags=%s" % tag)

        if limit:
            params.append("limit=%s" % limit)

        list_annotations_path += "?"
        list_annotations_path += "&".join(params)

        r = self.client.GET(list_annotations_path)

        return r

    def add_annotation(
        self,
        dashboard_id=None,
        panel_id=None,
        time_from=None,
        time_to=None,
        tags=[],
        text=None,
    ):

        """
        https://grafana.com/docs/grafana/latest/http_api/annotations/#create-annotation

        :param dashboard_id:
        :param panel_id
        :param time_from:
        :param time_to:
        :param tags:
        :param text:
        :return:
        """

        annotations_path = "/annotations"
        payload = {
            "dashboardId": dashboard_id,
            "panelId": panel_id,
            "time": time_from,
            "timeEnd": time_to,
            "tags": tags,
            "text": text,
        }

        r = self.client.POST(annotations_path, json=payload)

        return r

    def add_annotation_graphite(
        self,
        what=None,
        tags=[],
        when=None,
        data=None,
    ):
        """
        https://grafana.com/docs/grafana/latest/http_api/annotations/#create-annotation-in-graphite-format

        :param what:
        :param tags:
        :param when:
        :param data:
        :return:
        """

        annotations_path = "/annotations/graphite"
        payload = {"what": what, "tags": tags, "when": when, "data": data}

        r = self.client.POST(annotations_path, json=payload)

        return r

    def update_annotation(
        self,
        annotations_id,
        time_from=None,
        time_to=None,
        tags=[],
        text=None,
    ):
        """
        https://grafana.com/docs/grafana/latest/http_api/annotations/#update-annotation

        :param time_from:
        :param time_to:
        :param tags:
        :param text:
        :return:
        """
        annotations_path = "/annotations/{}".format(annotations_id)
        payload = {"time": time_from, "timeEnd": time_to, "tags": tags, "text": text}

        r = self.client.PUT(annotations_path, json=payload)

        return r

    def partial_update_annotation(
        self,
        annotations_id,
        time_from=None,
        time_to=None,
        tags=[],
        text=None,
    ):
        """
        https://grafana.com/docs/grafana/latest/http_api/annotations/#patch-annotation

        :param annotations_id:
        :param time_from:
        :param time_to:
        :param tags:
        :param text:
        :return:
        """
        annotations_path = "/annotations/{}".format(annotations_id)
        payload = {}

        payload = {"time": time_from, "timeEnd": time_to, "tags": tags, "text": text}

        r = self.client.PATCH(annotations_path, json=payload)

        return r

    def delete_annotations_by_id(self, annotations_id=None):

        """
        https://grafana.com/docs/grafana/latest/http_api/annotations/#delete-annotation-by-id

        :param annotations_id:
        :return:
        """
        annotations_path = "/annotations/{}".format(annotations_id)
        r = self.client.DELETE(annotations_path)

        return r



from .admin import Admin
from .annotations import Annotations
from .base import Base
from .dashboard import Dashboard
from .datasource import Datasource
from .folder import Folder
from .health import Health
from .notifications import Notifications
from .organization import Organization, Organizations
from .search import Search
from .snapshots import Snapshots
from .team import Teams
from .user import User, Users



from .base import Base


class Folder(Base):
    def __init__(self, client):
        super(Folder, self).__init__(client)
        self.client = client

    def get_all_folders(self):
        """

        :return:
        """
        path = "/folders"
        r = self.client.GET(path)
        return r

    def get_folder(self, uid):
        """

        :param uid:
        :return:
        """
        path = "/folders/%s" % uid
        r = self.client.GET(path)
        return r

    def create_folder(self, title, uid=None):
        """

        :param title:
        :param uid:
        :return:
        """
        json_data = dict(title=title)
        if uid is not None:
            json_data["uid"] = uid
        return self.client.POST("/folders", json=json_data)

    def update_folder(self, uid, title, version=None, overwrite=False):
        """

        :param uid:
        :param title:
        :param version:
        :param overwrite:
        :return:
        """
        body = {"title": title}
        if version is not None:
            body["version"] = version
        if overwrite:
            body["overwrite"] = True

        path = "/folders/%s" % uid
        r = self.client.PUT(path, json=body)
        return r

    def delete_folder(self, uid):
        """

        :param uid:
        :return:
        """
        path = "/folders/%s" % uid
        r = self.client.DELETE(path)
        return r

    def get_folder_by_id(self, folder_id):
        """

        :param folder_id:
        :return:
        """
        path = "/folders/id/%s" % folder_id
        r = self.client.GET(path)
        return r

    def get_folder_permissions(self, uid):
        """

        :return:
        """
        path = "/folders/%s/permissions" % uid
        r = self.client.GET(path)
        return r

    def update_folder_permissions(self, uid, items):
        """

        :param uid:
        :param items:
        :return:
        """
        update_folder_permissions_path = "/folders/%s/permissions" % uid
        r = self.client.POST(update_folder_permissions_path, json=items)
        return r



from .base import Base


class Health(Base):
    def __init__(self, client):
        super(Health, self).__init__(client)
        self.client = client

    def check(self):
        """

        :return:
        """
        path = "/health"
        r = self.client.GET(path)
        return r



import unittest

import requests_mock

from grafana_client import GrafanaApi


class SnapshotTestCase(unittest.TestCase):
    def setUp(self):
        self.grafana = GrafanaApi(("admin", "admin"), host="localhost", url_path_prefix="", protocol="http")

    @requests_mock.Mocker()
    def test_create_new_snapshot(self, m):
        m.post(
            "http://localhost/api/snapshots",
            json={
                "deleteKey": "XXXXXXX",
                "deleteUrl": "myurl/api/snapshots.py-delete/XXXXXXX",
                "key": "YYYYYYY",
                "url": "myurl/dashboard/snapshot/YYYYYYY",
            },
        )
        snapshot = self.grafana.snapshots.create_new_snapshot(
            dashboard={
                "editable": "false",
                "hideControls": "true",
                "nav": [{"enable": "false", "type": "timepicker"}],
                "rows": [{}],
                "style": "dark",
                "tags": [],
                "templating": {"list": []},
                "time": {},
                "timezone": "browser",
                "title": "Home",
                "version": 5,
            },
            name="Test",
            key="YYYYYYY",
            delete_key="XXXXXXX",
            external=True,
            expires=3600,
        )
        self.assertEqual(snapshot["key"], "YYYYYYY")

    @requests_mock.Mocker()
    def test_create_new_snapshot_without_optional(self, m):
        m.post(
            "http://localhost/api/snapshots",
            json={
                "deleteKey": "XXXXXXX",
                "deleteUrl": "myurl/api/snapshots.py-delete/XXXXXXX",
                "key": "YYYYYYY",
                "url": "myurl/dashboard/snapshot/YYYYYYY",
            },
        )
        snapshot = self.grafana.snapshots.create_new_snapshot(
            dashboard={
                "editable": "false",
                "hideControls": "true",
                "nav": [{"enable": "false", "type": "timepicker"}],
                "rows": [{}],
                "style": "dark",
                "tags": [],
                "templating": {"list": []},
                "time": {},
                "timezone": "browser",
                "title": "Home",
                "version": 5,
            }
        )
        self.assertEqual(snapshot["key"], "YYYYYYY")

    @requests_mock.Mocker()
    def test_get_dashboard_snapshots(self, m):
        m.get(
            "http://localhost/api/dashboard/snapshots",
            json=[
                {
                    "id": 8,
                    "name": "Home",
                    "key": "YYYYYYY",
                    "orgId": 1,
                    "userId": 1,
                    "external": False,
                    "externalUrl": "",
                    "expires": "2200-13-32T25:23:23+02:00",
                    "created": "2200-13-32T28:24:23+02:00",
                    "updated": "2200-13-32T28:24:23+02:00",
                }
            ],
        )
        dashboards = self.grafana.snapshots.get_dashboard_snapshots()
        self.assertEqual(len(dashboards), 1)

    @requests_mock.Mocker()
    def test_get_snapshot_by_key(self, m):
        m.get(
            "http://localhost/api/snapshots/YYYYYYY",
            json=[
                {
                    "id": 8,
                    "name": "Home",
                    "key": "YYYYYYY",
                    "orgId": 1,
                    "userId": 1,
                    "external": False,
                    "externalUrl": "",
                    "expires": "2200-13-32T25:23:23+02:00",
                    "created": "2200-13-32T28:24:23+02:00",
                    "updated": "2200-13-32T28:24:23+02:00",
                }
            ],
        )
        dashboards = self.grafana.snapshots.get_snapshot_by_key(key="YYYYYYY")
        self.assertEqual(len(dashboards), 1)

    @requests_mock.Mocker()
    def test_delete_snapshot_by_key(self, m):
        m.delete(
            "http://localhost/api/snapshots/YYYYYYY",
            json={"message": "Snapshot deleted. It might take an hour " "before it's cleared from any CDN " "caches."},
        )
        annotation = self.grafana.snapshots.delete_snapshot_by_key(snapshot_id="YYYYYYY")
        self.assertEqual(
            annotation["message"], "Snapshot deleted. It might take an hour before it's cleared from any " "CDN caches."
        )

    @requests_mock.Mocker()
    def test_delete_snapshot_by_delete_key(self, m):
        m.get(
            "http://localhost/api/snapshots-delete/XXXXXXX",
            json={"message": "Snapshot deleted. It might take an hour " "before it's cleared from any CDN " "caches."},
        )
        annotation = self.grafana.snapshots.delete_snapshot_by_delete_key(snapshot_delete_key="XXXXXXX")
        self.assertEqual(
            annotation["message"], "Snapshot deleted. It might take an hour before it's cleared from any " "CDN caches."
        )



import unittest

import requests_mock

from grafana_client import GrafanaApi


class OrganizationTestCase(unittest.TestCase):
    def setUp(self):
        self.grafana = GrafanaApi(("admin", "admin"), host="localhost", url_path_prefix="", protocol="http")

    @requests_mock.Mocker()
    def test_delete_snapshot_by_key(self, m):
        m.delete("http://localhost/api/orgs/1/users/2", json={"message": "User removed from organization"})
        annotation = self.grafana.organizations.organization_user_delete(organization_id=1, user_id=2)
        self.assertEqual(annotation["message"], "User removed from organization")

    @requests_mock.Mocker()
    def test_organization_preference_get(self, m):
        m.get("http://localhost/api/org/preferences", json={"theme": "", "homeDashboardId": 0, "timezone": ""})

        result = self.grafana.organizations.organization_preference_get()
        self.assertEqual(result["homeDashboardId"], 0)

    @requests_mock.Mocker()
    def test_organization_preference_update(self, m):
        m.put("http://localhost/api/org/preferences", json={"message": "Preferences updated"})
        preference = self.grafana.organizations.organization_preference_update(
            theme="", home_dashboard_id=0, timezone="utc"
        )
        self.assertEqual(preference["message"], "Preferences updated")

    @requests_mock.Mocker()
    def test_organization_user_update(self, m):
        m.patch("http://localhost/api/orgs/1/users/2", json={"message": "Organization user updated"})
        preference = self.grafana.organizations.organization_user_update(
            organization_id=1, user_id=2, user_role="Admin"
        )
        self.assertEqual(preference["message"], "Organization user updated")

    @requests_mock.Mocker()
    def test_organization_user_add(self, m):
        m.post("http://localhost/api/orgs/1/users", json={"message": "User added to organization"})
        preference = self.grafana.organizations.organization_user_add(
            organization_id=1, user={"loginOrEmail": "user", "role": "Viewer"}
        )
        self.assertEqual(preference["message"], "User added to organization")

    @requests_mock.Mocker()
    def test_organization_user_list(self, m):
        m.get(
            "http://localhost/api/orgs/1/users",
            json=[{"orgId": 1, "userId": 1, "email": "admin@mygraf.com", "login": "admin", "role": "Admin"}],
        )
        users = self.grafana.organizations.organization_user_list(organization_id=1)
        self.assertEqual(len(users), 1)

    @requests_mock.Mocker()
    def test_list_organization(self, m):
        m.get(
            "http://localhost/api/orgs",
            json=[{"orgId": 1, "userId": 1, "email": "admin@mygraf.com", "login": "admin", "role": "Admin"}],
        )
        users = self.grafana.organizations.list_organization()
        self.assertEqual(len(users), 1)

    @requests_mock.Mocker()
    def test_get_current_organization(self, m):
        m.get("http://localhost/api/org", json={"id": 1, "name": "Main Org."})
        orgs = self.grafana.organization.get_current_organization()
        self.assertEqual(orgs["name"], "Main Org.")

    @requests_mock.Mocker()
    def test_update_current_organization(self, m):
        m.put("http://localhost/api/org", json={"message": "Organization updated"})
        org = self.grafana.organization.update_current_organization(organization={"name": "Main Org."})
        self.assertEqual(org["message"], "Organization updated")

    @requests_mock.Mocker()
    def test_update_organization(self, m):
        m.put("http://localhost/api/orgs/1", json={"message": "Organization updated"})
        preference = self.grafana.organizations.update_organization(
            organization_id=1, organization={"name": "Main Org 2."}
        )
        self.assertEqual(preference["message"], "Organization updated")

    @requests_mock.Mocker()
    def test_delete_organization(self, m):
        m.delete("http://localhost/api/orgs/1", json={"message": "Organization deleted"})
        preference = self.grafana.organizations.delete_organization(organization_id=1)
        self.assertEqual(preference["message"], "Organization deleted")

    @requests_mock.Mocker()
    def test_create_organization(self, m):
        m.post("http://localhost/api/orgs", json={"orgId": "1", "message": "Organization created"})
        preference = self.grafana.organization.create_organization(organization={"name": "New Org."})
        self.assertEqual(preference["message"], "Organization created")

    @requests_mock.Mocker()
    def test_delete_user_current_organization(self, m):
        m.delete("http://localhost/api/org/users/1", json={"message": "User removed from organization"})
        preference = self.grafana.organization.delete_user_current_organization(user_id=1)
        self.assertEqual(preference["message"], "User removed from organization")

    @requests_mock.Mocker()
    def test_add_user_current_organization(self, m):
        m.post("http://localhost/api/org/users", json={"message": "User added to organization"})
        preference = self.grafana.organization.add_user_current_organization({"role": "Admin", "loginOrEmail": "admin"})
        self.assertEqual(preference["message"], "User added to organization")

    @requests_mock.Mocker()
    def test_update_user_current_organization(self, m):
        m.patch("http://localhost/api/org/users/1", json={"message": "Organization user updated"})
        preference = self.grafana.organization.update_user_current_organization(
            user_id=1,
            user={
                "role": "Viewer",
            },
        )
        self.assertEqual(preference["message"], "Organization user updated")

    @requests_mock.Mocker()
    def test_get_current_organization_users(self, m):
        m.get(
            "http://localhost/api/org/users",
            json=[{"orgId": 1, "userId": 1, "email": "admin@mygraf.com", "login": "admin", "role": "Admin"}],
        )
        org = self.grafana.organization.get_current_organization_users()
        self.assertEqual(len(org), 1)

    @requests_mock.Mocker()
    def test_find_organization(self, m):
        m.get(
            "http://localhost/api/orgs/name/Main",
            json={
                "id": 1,
                "name": "Main Org.",
                "address": {"address1": "", "address2": "", "city": "", "zipCode": "", "state": "", "country": ""},
            },
        )
        org = self.grafana.organization.find_organization(org_name="Main")
        self.assertEqual(org["id"], 1)

    @requests_mock.Mocker()
    def test_switch_organization(self, m):
        m.post("http://localhost/api/user/using/2", json={"message": "Active organization changed"})
        preference = self.grafana.organizations.switch_organization(organization_id=2)
        self.assertEqual(preference["message"], "Active organization changed")



from .base import Base


class Datasource(Base):
    def __init__(self, client):
        super(Datasource, self).__init__(client)
        self.client = client

    def find_datasource(self, datasource_name):
        """

        :param datasource_name:
        :return:
        """
        get_datasource_path = "/datasources/name/%s" % datasource_name
        r = self.client.GET(get_datasource_path)
        return r

    def get_datasource_by_id(self, datasource_id):
        """

        :param datasource_id:
        :return:
        """
        get_datasource_path = "/datasources/%s" % datasource_id
        r = self.client.GET(get_datasource_path)
        return r

    def get_datasource_by_name(self, datasource_name):
        """

        :param datasource_name:
        :return:
        """
        get_datasource_path = "/datasources/name/%s" % datasource_name
        r = self.client.GET(get_datasource_path)
        return r

    def get_datasource_id_by_name(self, datasource_name):
        """

        :param datasource_name:
        :return:
        """
        get_datasource_path = "/datasources/id/%s" % datasource_name
        r = self.client.GET(get_datasource_path)
        return r

    def create_datasource(self, datasource):
        """

        :param datasource:
        :return:
        """
        create_datasources_path = "/datasources"
        r = self.client.POST(create_datasources_path, json=datasource)
        return r

    def update_datasource(self, datasource_id, datasource):
        """

        :param datasource_id:
        :param datasource:
        :return:
        """
        update_datasource = "/datasources/%s" % datasource_id
        r = self.client.PUT(update_datasource, json=datasource)
        return r

    def list_datasources(self):
        """

        :return:
        """
        list_datasources_path = "/datasources"
        r = self.client.GET(list_datasources_path)
        return r

    def delete_datasource_by_id(self, datasource_id):
        """

        :param datasource_id:
        :return:
        """
        delete_datasource = "/datasources/%s" % datasource_id
        r = self.client.DELETE(delete_datasource)
        return r

    def delete_datasource_by_name(self, datasource_name):
        """

        :param datasource_name:
        :return:
        """
        delete_datasource = "/datasources/name/%s" % datasource_name
        r = self.client.DELETE(delete_datasource)
        return r

    def get_datasource_proxy_data(
        self, datasource_id, query_type="query", version="v1", expr=None, time=None, start=None, end=None, step=None
    ):
        """

        :param datasource_id:
        :param version: api_version currently v1
        :param query_type: query_range |query
        :param expr: expr to query

        :return: r (dict)
        """
        get_datasource_path = "/datasources/proxy/{0}" "/api/{1}/{2}?query={3}".format(
            datasource_id, version, query_type, expr
        )
        if query_type == "query_range":
            get_datasource_path = get_datasource_path + "&start={0}&end={1}&step={2}".format(start, end, step)
        else:
            get_datasource_path = get_datasource_path + "&time={}".format(time)
        r = self.client.GET(get_datasource_path)
        return r



import unittest

import requests_mock

from grafana_client import GrafanaApi


class DashboardTestCase(unittest.TestCase):
    def setUp(self):
        self.grafana = GrafanaApi(("admin", "admin"), host="localhost", url_path_prefix="", protocol="http")

    @requests_mock.Mocker()
    def test_get_dashboard(self, m):
        m.get(
            "http://localhost/api/dashboards/uid/cIBgcSjkk",
            json={
                "dashboard": {
                    "id": 1,
                    "uid": "cIBgcSjkk",
                    "title": "Production Overview",
                    "tags": ["templated"],
                    "timezone": "browser",
                    "schemaVersion": 16,
                    "version": 0,
                },
                "meta": {
                    "isStarred": "false",
                    "url": "/d/cIBgcSjkk/production-overview",
                    "slug": "production-overview",
                },
            },
        )
        dashboard = self.grafana.dashboard.get_dashboard("cIBgcSjkk")
        self.assertEqual(dashboard["dashboard"]["uid"], "cIBgcSjkk")

    @requests_mock.Mocker()
    def test_update_dashboard(self, m):
        """
        Verify a general dashboard update.
        """
        m.post(
            "http://localhost/api/dashboards/db",
            json={
                "id": 1,
                "uid": "cIBgcSjkk",
                "url": "/d/cIBgcSjkk/production-overview",
                "status": "success",
                "version": 1,
                "slug": "production-overview",
            },
        )
        dashboard = self.grafana.dashboard.update_dashboard(
            {
                "dashboard": {
                    "id": 1,
                    "uid": "cIBgcSjkk",
                    "title": "Production Overview",
                    "tags": ["templated"],
                    "timezone": "browser",
                    "schemaVersion": 16,
                    "version": 0,
                },
                "folderId": 0,
                "overwrite": "false",
            }
        )

        self.assertEqual(dashboard["uid"], "cIBgcSjkk")
        self.assertEqual(dashboard["status"], "success")

    @requests_mock.Mocker()
    def test_update_dashboard_roundtrip_folder_1(self, m):
        """
        Verify that a dashboard update will use the "folderId"
        from the nested "meta" object.
        This is important when roundtripping dashboard payloads.
        """
        m.post("http://localhost/api/dashboards/db", json={})
        self.grafana.dashboard.update_dashboard(
            {
                "meta": {
                    "folderId": 123,
                },
                "dashboard": {},
            }
        )

        self.assertEqual(m.last_request.json()["folderId"], 123)

    @requests_mock.Mocker()
    def test_update_dashboard_roundtrip_folder_2(self, m):
        """
        Verify that a dashboard update will use the "folderId"
        from the toplevel dashboard payload, even if it is present
        within the nested "meta" object.
        This is important when roundtripping dashboard payloads and
        intentionally wanting to move the dashboard to a different folder.
        """
        m.post("http://localhost/api/dashboards/db", json={})
        self.grafana.dashboard.update_dashboard(
            {
                "meta": {
                    "folderId": 123,
                },
                "dashboard": {},
                "folderId": 456,
            }
        )

        self.assertEqual(m.last_request.json()["folderId"], 456)

    @requests_mock.Mocker()
    def test_get_home_dashboard(self, m):
        m.get(
            "http://localhost/api/dashboards/home",
            json={
                "dashboard": {
                    "editable": "false",
                    "hideControls": "true",
                    "nav": [{"enable": "false", "type": "timepicker"}],
                    "style": "dark",
                    "tags": [],
                    "templating": {"list": []},
                    "time": {},
                    "timezone": "browser",
                    "title": "Home",
                    "version": 5,
                },
                "meta": {
                    "isHome": "true",
                    "canSave": "false",
                    "canEdit": "false",
                    "canStar": "false",
                    "url": "",
                    "expires": "0001-01-01T00:00:00Z",
                    "created": "0001-01-01T00:00:00Z",
                },
            },
        )
        dashboard = self.grafana.dashboard.get_home_dashboard()
        self.assertEqual(dashboard["meta"]["isHome"], "true")

    @requests_mock.Mocker()
    def test_delete_dashboard(self, m):
        m.delete("http://localhost/api/dashboards/uid/cIBgcSjkk", json={"title": "Production Overview"})
        response = self.grafana.dashboard.delete_dashboard("cIBgcSjkk")
        self.assertEqual(response["title"], "Production Overview")

    @requests_mock.Mocker()
    def test_get_dashboards_tags(self, m):
        m.get("http://localhost/api/dashboards/tags", json=[{"term": "tag1", "count": 1}, {"term": "tag2", "count": 4}])
        tags = self.grafana.dashboard.get_dashboards_tags()
        self.assertEqual(len(tags), 2)
        self.assertEqual(tags[0]["term"], "tag1")

    @requests_mock.Mocker()
    def test_get_dashboard_permissions(self, m):
        m.get(
            "http://localhost/api/dashboards/id/1/permissions",
            json=[
                {
                    "id": 1,
                    "dashboardId": 1,
                    "created": "2017-06-20T02:00:00+02:00",
                    "updated": "2017-06-20T02:00:00+02:00",
                    "userId": 0,
                    "userLogin": "",
                    "userEmail": "",
                    "teamId": 0,
                    "team": "",
                    "role": "Viewer",
                    "permission": 1,
                    "permissionName": "View",
                    "uid": "",
                    "title": "",
                    "slug": "",
                    "isFolder": "false",
                    "url": "",
                },
                {
                    "id": 2,
                    "dashboardId": 1,
                    "created": "2017-06-20T02:00:00+02:00",
                    "updated": "2017-06-20T02:00:00+02:00",
                    "userId": 0,
                    "userLogin": "",
                    "userEmail": "",
                    "teamId": 0,
                    "team": "",
                    "role": "Editor",
                    "permission": 2,
                    "permissionName": "Edit",
                    "uid": "",
                    "title": "",
                    "slug": "",
                    "isFolder": "false",
                    "url": "",
                },
            ],
        )
        permissions = self.grafana.dashboard.get_dashboard_permissions(1)
        self.assertEqual(len(permissions), 2)
        self.assertEqual(permissions[0]["dashboardId"], 1)

    @requests_mock.Mocker()
    def test_update_dashboard_permissions(self, m):
        m.post("http://localhost/api/dashboards/id/1/permissions", json={"message": "Dashboard permissions updated"})
        permissions = self.grafana.dashboard.update_dashboard_permissions(
            1,
            {
                "items": [
                    {"role": "Viewer", "permission": 1},
                    {"role": "Editor", "permission": 2},
                    {"teamId": 1, "permission": 1},
                    {"userId": 11, "permission": 4},
                ]
            },
        )
        self.assertEqual(permissions["message"], "Dashboard permissions updated")



import unittest

import requests_mock

from grafana_client import GrafanaApi


class AdminTestCase(unittest.TestCase):
    def setUp(self):
        self.grafana = GrafanaApi(("admin", "admin"), host="localhost", url_path_prefix="", protocol="http")

    @requests_mock.Mocker()
    def test_settings(self, m):
        m.get(
            "http://localhost/api/admin/settings",
            json={
                "DEFAULT": {"app_mode": "production"},
                "analytics": {"google_analytics_ua_id": "", "reporting_enabled": "false"},
                "auth.anonymous": {"enabled": "true", "org_name": "Main Org.", "org_role": "Viewer"},
                "auth.basic": {"enabled": "false"},
                "auth.github": {
                    "allow_sign_up": "false",
                    "allowed_domains": "",
                    "allowed_organizations": "",
                    "api_url": "https://api.github.com/user",
                    "auth_url": "https://github.com/login/oauth/authorize",
                    "client_id": "some_id",
                    "client_secret": "************",
                    "enabled": "false",
                    "scopes": "user:email,read:org",
                    "team_ids": "",
                    "token_url": "https://github.com/login/oauth/access_token",
                },
                "auth.google": {
                    "allow_sign_up": "false",
                    "allowed_domains": "",
                    "api_url": "https://www.googleapis.com/oauth2/v1/userinfo",
                    "auth_url": "https://accounts.google.com/o/oauth2/auth",
                    "client_id": "some_client_id",
                    "client_secret": "************",
                    "enabled": "false",
                    "scopes": "https://www.googleapis.com/auth/userinfo.profile https://www.googleapis.com/auth/userinfo.email",
                    "token_url": "https://accounts.google.com/o/oauth2/token",
                },
                "auth.ldap": {"config_file": "/etc/grafana/ldap.toml", "enabled": "false"},
                "auth.proxy": {
                    "auto_sign_up": "true",
                    "enabled": "false",
                    "header_name": "X-WEBAUTH-USER",
                    "header_property": "username",
                },
                "dashboards.json": {"enabled": "false", "path": "/var/lib/grafana/dashboards"},
                "database": {
                    "host": "127.0.0.1:0000",
                    "name": "grafana",
                    "password": "************",
                    "path": "grafana.db",
                    "ssl_mode": "disable",
                    "type": "sqlite3",
                    "user": "root",
                },
                "emails": {"templates_pattern": "emails/*.html", "welcome_email_on_sign_up": "false"},
                "log": {"buffer_len": "10000", "level": "Info", "mode": "file"},
                "log.console": {"level": ""},
                "log.file": {
                    "daily_rotate": "true",
                    "file_name": "",
                    "level": "",
                    "log_rotate": "true",
                    "max_days": "7",
                    "max_lines": "1000000",
                    "max_lines_shift": "28",
                    "max_size_shift": "",
                },
                "paths": {"data": "/tsdb/grafana", "logs": "/logs/apps/grafana"},
                "security": {
                    "admin_password": "************",
                    "admin_user": "admin",
                    "cookie_remember_name": "grafana_remember",
                    "cookie_username": "grafana_user",
                    "disable_gravatar": "false",
                    "login_remember_days": "7",
                    "secret_key": "************",
                },
                "server": {
                    "cert_file": "",
                    "cert_key": "",
                    "domain": "mygraf.com",
                    "enable_gzip": "false",
                    "enforce_domain": "false",
                    "http_addr": "127.0.0.1",
                    "http_port": "0000",
                    "protocol": "http",
                    "root_url": "%(protocol)s://%(domain)s:%(http_port)s/",
                    "router_logging": "true",
                    "data_proxy_logging": "true",
                    "static_root_path": "public",
                },
                "session": {
                    "cookie_name": "grafana_sess",
                    "cookie_secure": "false",
                    "gc_interval_time": "",
                    "provider": "file",
                    "provider_config": "sessions",
                    "session_life_time": "86400",
                },
                "smtp": {
                    "cert_file": "",
                    "enabled": "false",
                    "from_address": "admin@grafana.localhost",
                    "from_name": "Grafana",
                    "ehlo_identity": "dashboard.example.com",
                    "host": "localhost:25",
                    "key_file": "",
                    "password": "************",
                    "skip_verify": "false",
                    "user": "",
                },
                "users": {
                    "allow_org_create": "true",
                    "allow_sign_up": "false",
                    "auto_assign_org": "true",
                    "auto_assign_org_role": "Viewer",
                },
            },
        )
        admin = self.grafana.admin.settings()
        self.assertEqual(admin["users"]["allow_org_create"], "true")

    @requests_mock.Mocker()
    def test_stats(self, m):
        m.get(
            "http://localhost/api/admin/stats",
            json={
                "users": 2,
                "orgs": 1,
                "dashboards": 4,
                "snapshots": 2,
                "tags": 6,
                "datasources": 1,
                "playlists": 1,
                "stars": 2,
                "alerts": 2,
                "activeUsers": 1,
            },
        )
        stats = self.grafana.admin.stats()
        self.assertEqual(len(stats), 10)

    @requests_mock.Mocker()
    def test_create_user(self, m):
        m.post("http://localhost/api/admin/users", json={"id": 5, "message": "User created"})
        user = self.grafana.admin.create_user(
            {"name": "User", "email": "user@graf.com", "login": "user", "password": "userpassword"}
        )
        self.assertEqual(user["message"], "User created")

    @requests_mock.Mocker()
    def test_change_user_password(self, m):
        m.put("http://localhost/api/admin/users/2/password", json={"message": "User password updated"})
        user = self.grafana.admin.change_user_password(user_id=2, password="password")
        self.assertEqual(user["message"], "User password updated")

    @requests_mock.Mocker()
    def test_change_user_permissions(self, m):
        m.put("http://localhost/api/admin/users/2/permissions", json={"message": "User permissions updated"})
        user = self.grafana.admin.change_user_permissions(user_id=2, is_grafana_admin=True)
        self.assertEqual(user["message"], "User permissions updated")

    @requests_mock.Mocker()
    def test_delete_user(self, m):
        m.delete("http://localhost/api/admin/users/2", json={"message": "User deleted"})
        user = self.grafana.admin.delete_user(user_id=2)
        self.assertEqual(user["message"], "User deleted")

    @requests_mock.Mocker()
    def test_pause_all_alerts(self, m):
        m.post(
            "http://localhost/api/admin/pause-all-alerts",
            json={"state": "Paused", "message": "alert paused", "alertsAffected": 1},
        )
        pause = self.grafana.admin.pause_all_alerts(pause="True")
        self.assertEqual(pause["message"], "alert paused")



import unittest

import requests_mock

from grafana_client import GrafanaApi
from grafana_client.client import (
    GrafanaBadInputError,
    GrafanaClientError,
    GrafanaServerError,
    GrafanaUnauthorizedError,
)


class NotificationsTestCase(unittest.TestCase):
    def setUp(self):
        self.grafana = GrafanaApi(("admin", "admin"), host="localhost", url_path_prefix="", protocol="http")

    @requests_mock.Mocker()
    def test_get_channels(self, mock):
        mock.get(
            "http://localhost/api/alert-notifications",
            json=[
                {
                    "id": 1,
                    "uid": "team-a-email-notifier",
                    "name": "Team A",
                    "type": "email",
                    "isDefault": False,
                    "sendReminder": False,
                    "disableResolveMessage": False,
                    "settings": {"addresses": "dev@grafana.com"},
                    "created": "2018-04-23T14:44:09+02:00",
                    "updated": "2018-08-20T15:47:49+02:00",
                }
            ],
        )
        notification_channels = self.grafana.notifications.get_channels()
        self.assertEqual(len(notification_channels), 1)

        channel = notification_channels[0]
        self.assertEqual(channel["id"], 1)
        self.assertEqual(channel["uid"], "team-a-email-notifier")
        self.assertEqual(channel["name"], "Team A")
        self.assertEqual(channel["type"], "email")
        self.assertFalse(channel["isDefault"])
        self.assertFalse(channel["sendReminder"])
        self.assertFalse(channel["disableResolveMessage"])
        self.assertEqual(channel["settings"]["addresses"], "dev@grafana.com")
        self.assertEqual(channel["created"], "2018-04-23T14:44:09+02:00")
        self.assertEqual(channel["updated"], "2018-08-20T15:47:49+02:00")

    @requests_mock.Mocker()
    def test_lookup_channels(self, mock):
        mock.get(
            "http://localhost/api/alert-notifications/lookup",
            json=[
                {
                    "id": 1,
                    "uid": "000000001",
                    "name": "Test",
                    "type": "email",
                    "isDefault": False,
                },
                {
                    "id": 2,
                    "uid": "000000002",
                    "name": "Slack",
                    "type": "slack",
                    "isDefault": False,
                },
            ],
        )
        notification_channels = self.grafana.notifications.lookup_channels()
        self.assertEqual(len(notification_channels), 2)

        channel_1 = notification_channels[0]
        self.assertEqual(channel_1["id"], 1)
        self.assertEqual(channel_1["uid"], "000000001")
        self.assertEqual(channel_1["name"], "Test")
        self.assertEqual(channel_1["type"], "email")
        self.assertFalse(channel_1["isDefault"])

        channel_2 = notification_channels[1]
        self.assertEqual(channel_2["id"], 2)
        self.assertEqual(channel_2["uid"], "000000002")
        self.assertEqual(channel_2["name"], "Slack")
        self.assertEqual(channel_2["type"], "slack")
        self.assertFalse(channel_2["isDefault"])

    @requests_mock.Mocker()
    def test_get_channel_by_uid(self, mock):
        mock.get(
            "http://localhost/api/alert-notifications/uid/team-a-email-notifier",
            json={
                "id": 1,
                "uid": "team-a-email-notifier",
                "name": "Team A",
                "type": "email",
                "isDefault": False,
                "sendReminder": False,
                "disableResolveMessage": False,
                "settings": {"addresses": "dev@grafana.com"},
                "created": "2018-04-23T14:44:09+02:00",
                "updated": "2018-08-20T15:47:49+02:00",
            },
        )

        channel = self.grafana.notifications.get_channel_by_uid("team-a-email-notifier")
        self.assertEqual(channel["id"], 1)
        self.assertEqual(channel["uid"], "team-a-email-notifier")
        self.assertEqual(channel["name"], "Team A")
        self.assertEqual(channel["type"], "email")
        self.assertFalse(channel["isDefault"])
        self.assertFalse(channel["sendReminder"])
        self.assertFalse(channel["disableResolveMessage"])
        self.assertEqual(channel["settings"]["addresses"], "dev@grafana.com")
        self.assertEqual(channel["created"], "2018-04-23T14:44:09+02:00")
        self.assertEqual(channel["updated"], "2018-08-20T15:47:49+02:00")

    @requests_mock.Mocker()
    def test_get_channel_by_id(self, mock):
        mock.get(
            "http://localhost/api/alert-notifications/1",
            json={
                "id": 1,
                "uid": "team-a-email-notifier",
                "name": "Team A",
                "type": "email",
                "isDefault": False,
                "sendReminder": False,
                "disableResolveMessage": False,
                "settings": {"addresses": "dev@grafana.com"},
                "created": "2018-04-23T14:44:09+02:00",
                "updated": "2018-08-20T15:47:49+02:00",
            },
        )

        channel = self.grafana.notifications.get_channel_by_id(1)
        self.assertEqual(channel["id"], 1)
        self.assertEqual(channel["uid"], "team-a-email-notifier")
        self.assertEqual(channel["name"], "Team A")
        self.assertEqual(channel["type"], "email")
        self.assertFalse(channel["isDefault"])
        self.assertFalse(channel["sendReminder"])
        self.assertFalse(channel["disableResolveMessage"])
        self.assertEqual(channel["settings"]["addresses"], "dev@grafana.com")
        self.assertEqual(channel["created"], "2018-04-23T14:44:09+02:00")
        self.assertEqual(channel["updated"], "2018-08-20T15:47:49+02:00")

    @requests_mock.Mocker()
    def test_create_channel(self, mock):
        mock.post(
            "http://localhost/api/alert-notifications",
            json={
                "id": 2,
                "uid": "new-alert-notification",
                "name": "new alert notification",
                "type": "email",
                "isDefault": False,
                "sendReminder": False,
                "disableResolveMessage": False,
                "settings": {"addresses": "dev@grafana.com"},
                "created": "2018-04-23T14:44:09+02:00",
                "updated": "2018-08-20T15:47:49+02:00",
            },
        )

        payload = {
            "uid": "new-alert-notification",
            "name": "new alert notification",
            "type": "email",
            "isDefault": False,
            "sendReminder": False,
            "settings": {"addresses": "dev@grafana.com"},
        }

        created_channel = self.grafana.notifications.create_channel(payload)
        self.assertEqual(created_channel["id"], 2)
        self.assertEqual(created_channel["uid"], "new-alert-notification")
        self.assertEqual(created_channel["name"], "new alert notification")
        self.assertEqual(created_channel["type"], "email")
        self.assertFalse(created_channel["isDefault"])
        self.assertFalse(created_channel["sendReminder"])
        self.assertFalse(created_channel["disableResolveMessage"])
        self.assertEqual(created_channel["settings"]["addresses"], "dev@grafana.com")
        self.assertEqual(created_channel["created"], "2018-04-23T14:44:09+02:00")
        self.assertEqual(created_channel["updated"], "2018-08-20T15:47:49+02:00")

    @requests_mock.Mocker()
    def test_update_channel_by_uid(self, mock):
        mock.put(
            "http://localhost/api/alert-notifications/uid/new-alert-notification",
            json={
                "id": 1,
                "uid": "new-alert-notification",
                "name": "new alert notification",
                "type": "email",
                "isDefault": False,
                "sendReminder": True,
                "frequency": "15m",
                "settings": {"addresses": "dev@grafana.com"},
                "created": "2017-01-01 12:34",
                "updated": "2020-01-01 12:34",
            },
        )

        payload = {
            "uid": "new-alert-notification",
            "name": "new alert notification",
            "type": "email",
            "isDefault": False,
            "sendReminder": True,
            "frequency": "15m",
            "settings": {"addresses": "dev@grafana.com"},
        }

        updated_channel = self.grafana.notifications.update_channel_by_uid("new-alert-notification", payload)
        self.assertEqual(updated_channel["id"], 1)
        self.assertEqual(updated_channel["uid"], "new-alert-notification")
        self.assertEqual(updated_channel["name"], "new alert notification")
        self.assertEqual(updated_channel["type"], "email")
        self.assertFalse(updated_channel["isDefault"])
        self.assertTrue(updated_channel["sendReminder"])
        self.assertEqual(updated_channel["frequency"], "15m")
        self.assertEqual(updated_channel["settings"]["addresses"], "dev@grafana.com")
        self.assertEqual(updated_channel["created"], "2017-01-01 12:34")
        self.assertEqual(updated_channel["updated"], "2020-01-01 12:34")

    @requests_mock.Mocker()
    def test_update_channel_by_id(self, mock):
        mock.put(
            "http://localhost/api/alert-notifications/1",
            json={
                "id": 1,
                "uid": "new-alert-notification",
                "name": "new alert notification",
                "type": "email",
                "isDefault": False,
                "sendReminder": True,
                "frequency": "15m",
                "settings": {"addresses": "dev@grafana.com"},
                "created": "2017-01-01 12:34",
                "updated": "2020-01-01 12:34",
            },
        )

        payload = {
            "uid": "new-alert-notification",
            "name": "new alert notification",
            "type": "email",
            "isDefault": False,
            "sendReminder": True,
            "frequency": "15m",
            "settings": {"addresses": "dev@grafana.com"},
        }

        updated_channel = self.grafana.notifications.update_channel_by_id(1, payload)
        self.assertEqual(updated_channel["id"], 1)
        self.assertEqual(updated_channel["uid"], "new-alert-notification")
        self.assertEqual(updated_channel["name"], "new alert notification")
        self.assertEqual(updated_channel["type"], "email")
        self.assertFalse(updated_channel["isDefault"])
        self.assertTrue(updated_channel["sendReminder"])
        self.assertEqual(updated_channel["frequency"], "15m")
        self.assertEqual(updated_channel["settings"]["addresses"], "dev@grafana.com")
        self.assertEqual(updated_channel["created"], "2017-01-01 12:34")
        self.assertEqual(updated_channel["updated"], "2020-01-01 12:34")

    @requests_mock.Mocker()
    def test_delete_notification_by_uid(self, mock):
        mock.delete(
            "http://localhost/api/alert-notifications/uid/new-alert-notification",
            json={"message": "Notification deleted"},
        )

        delete_response = self.grafana.notifications.delete_notification_by_uid("new-alert-notification")
        self.assertEqual(delete_response["message"], "Notification deleted")

    @requests_mock.Mocker()
    def test_delete_notification_by_id(self, mock):
        mock.delete(
            "http://localhost/api/alert-notifications/1",
            json={"message": "Notification deleted"},
        )

        delete_response = self.grafana.notifications.delete_notification_by_id(1)
        self.assertEqual(delete_response["message"], "Notification deleted")



import unittest

import requests_mock

from grafana_client import GrafanaApi
from grafana_client.client import (
    GrafanaBadInputError,
    GrafanaClientError,
    GrafanaServerError,
    GrafanaUnauthorizedError,
)


class AnnotationsTestCase(unittest.TestCase):
    def setUp(self):
        self.grafana = GrafanaApi(("admin", "admin"), host="localhost", url_path_prefix="", protocol="http")

    @requests_mock.Mocker()
    def test_search_dashboards(self, m):
        m.get(
            "http://localhost/api/search?folderIds=11&query=str_e&starred=false&tag=test_tag"
            "&type=dash-folder&dashboardIds=163&limit=10",
            json=[
                {
                    "id": 163,
                    "uid": "000000163",
                    "title": "Folder",
                    "url": "/dashboards/f/000000163/folder",
                    "type": "dash-folder",
                    "tags": [],
                    "isStarred": "false",
                    "uri": "db/folder",
                }
            ],
        )

        result = self.grafana.search.search_dashboards(
            query="str_e",
            folder_ids=11,
            starred="false",
            tag="test_tag",
            type_="dash-folder",
            dashboard_ids=163,
            limit=10,
        )
        self.assertEqual(result[0]["id"], 163)
        self.assertEqual(len(result), 1)

    @requests_mock.Mocker()
    def test_search_dashboards_with_out_filter(self, m):
        m.get("http://localhost/api/search", json={"message": "Not found"}, status_code=400)

        with self.assertRaises(GrafanaBadInputError):
            result = self.grafana.search.search_dashboards()



from .base import Base


class Organization(Base):
    def __init__(self, client):
        super(Organization, self).__init__(client)
        self.client = client

    def find_organization(self, org_name):
        """

        :param org_name:
        :return:
        """
        get_org_path = "/orgs/name/%s" % org_name
        r = self.client.GET(get_org_path)
        return r

    def get_current_organization(self):
        """

        :return:
        """
        get_current_organization_path = "/org"
        r = self.client.GET(get_current_organization_path)
        return r

    def create_organization(self, organization):
        """

        :param organization:
        :return:
        """
        create_orgs_path = "/orgs"
        r = self.client.POST(create_orgs_path, json={"name": organization["name"]})
        return r

    def update_current_organization(self, organization):
        """

        :param organization:
        :return:
        """
        update_current_organization_path = "/org"
        r = self.client.PUT(update_current_organization_path, json=organization)
        return r

    def get_current_organization_users(self):
        """

        :return:
        """
        get_current_organization_users_path = "/org/users"
        r = self.client.GET(get_current_organization_users_path)
        return r

    def add_user_current_organization(self, user):
        """

        :param user:
        :return:
        """
        add_user_current_organization_path = "/org/users"
        r = self.client.POST(add_user_current_organization_path, json=user)
        return r

    def update_user_current_organization(self, user_id, user):
        """

        :param user_id:
        :param user:
        :return:
        """
        update_user_current_organization_path = "/org/users/%s" % user_id
        r = self.client.PATCH(update_user_current_organization_path, json=user)
        return r

    def delete_user_current_organization(self, user_id):
        """

        :param user_id:
        :return:
        """
        delete_user_current_organization_path = "/org/users/%s" % user_id
        r = self.client.DELETE(delete_user_current_organization_path)
        return r


class Organizations(Base):
    def __init__(self, client):
        super(Organizations, self).__init__(client)
        self.client = client
        self.path = "/users"

    def update_organization(self, organization_id, organization):
        """

        :param organization_id:
        :param organization:
        :return:
        """
        update_org_path = "/orgs/%s" % organization_id
        r = self.client.PUT(update_org_path, json=organization)
        return r

    def delete_organization(self, organization_id):
        """

        :param organization_id:
        :return:
        """
        delete_org_path = "/orgs/%s" % organization_id
        r = self.client.DELETE(delete_org_path)
        return r

    def list_organization(self):
        """

        :return:
        """
        search_org_path = "/orgs"
        r = self.client.GET(search_org_path)
        return r

    def switch_organization(self, organization_id):
        """

        :param organization_id:
        :return:
        """
        switch_user_organization = "/user/using/%s" % organization_id
        r = self.client.POST(switch_user_organization)
        return r

    def organization_user_list(self, organization_id):
        """

        :param organization_id:
        :return:
        """
        users_in_org = "/orgs/%s/users" % organization_id
        r = self.client.GET(users_in_org)
        return r

    def organization_user_add(self, organization_id, user):
        """

        :param organization_id:
        :param user:
        :return:
        """
        add_user_path = "/orgs/%s/users" % organization_id
        r = self.client.POST(add_user_path, json=user)
        return r

    def organization_user_update(self, organization_id, user_id, user_role):
        """

        :param organization_id:
        :param user_id:
        :param user_role:
        :return:
        """
        patch_user = "/orgs/%s/users/%s" % (organization_id, user_id)
        r = self.client.PATCH(patch_user, json={"role": user_role})
        return r

    def organization_user_delete(self, organization_id, user_id):
        """

        :param organization_id:
        :param user_id:
        :return:
        """
        delete_user = "/orgs/%s/users/%s" % (organization_id, user_id)
        r = self.client.DELETE(delete_user)
        return r

    def organization_preference_get(self):
        """
        :return:
        """
        update_preference = "/org/preferences"
        r = self.client.GET(update_preference)
        return r

    def organization_preference_update(self, theme="", home_dashboard_id=0, timezone="utc"):
        """

        :param theme:
        :param home_dashboard_id:
        :param timezone:
        :return:
        """
        update_preference = "/org/preferences"
        r = self.client.PUT(
            update_preference,
            json={
                "theme": theme,
                "homeDashboardId": home_dashboard_id,
                "timezone": timezone,
            },
        )
        return r



import json
import unittest

import requests_mock

from grafana_client import GrafanaApi
from grafana_client.client import (
    GrafanaBadInputError,
    GrafanaClientError,
    GrafanaServerError,
    GrafanaUnauthorizedError,
)


class DatasourceTestCase(unittest.TestCase):
    def setUp(self):
        self.grafana = GrafanaApi(("admin", "admin"), host="localhost", url_path_prefix="", protocol="http")

    @requests_mock.Mocker()
    def test_find_datasource(self, m):
        m.get(
            "http://localhost/api/datasources/name/Prometheus",
            json={
                "id": 1,
                "uid": "h8KkCLt7z",
                "orgId": 1,
                "name": "Prometheus",
                "type": "prometheus",
                "typeName": "Prometheus",
                "typeLogoUrl": "public/app/plugins/datasource/prometheus/img/prometheus_logo.svg",
                "access": "proxy",
                "url": "http://localhost:9090",
                "password": "",
                "user": "",
                "database": "",
                "basicAuth": False,
                "isDefault": True,
                "jsonData": {"httpMethod": "POST"},
                "readOnly": False,
            },
        )

        result = self.grafana.datasource.find_datasource("Prometheus")
        self.assertEqual(result["type"], "prometheus")

    @requests_mock.Mocker()
    def test_find_datasource_not_existing(self, m):
        m.get(
            "http://localhost/api/datasources/name/it_doesnot_exist",
            json={"message": "Data source not found"},
            status_code=400,
        )

        with self.assertRaises(GrafanaBadInputError):
            result = self.grafana.datasource.find_datasource("it_doesnot_exist")

    @requests_mock.Mocker()
    def test_get_datasource_id_by_name(self, m):
        m.get("http://localhost/api/datasources/id/Prometheus", json={"id": 1})

        result = self.grafana.datasource.get_datasource_id_by_name("Prometheus")
        self.assertEqual(result["id"], 1)

    @requests_mock.Mocker()
    def test_list_datasources(self, m):
        m.get(
            "http://localhost/api/datasources",
            json=[
                {
                    "id": 1,
                    "uid": "h8KkCLt7z",
                    "orgId": 1,
                    "name": "Prometheus",
                    "type": "prometheus",
                    "typeName": "Prometheus",
                    "typeLogoUrl": "public/app/plugins/datasource/prometheus/img/prometheus_logo.svg",
                    "access": "proxy",
                    "url": "http://localhost:9090",
                    "password": "",
                    "user": "",
                    "database": "",
                    "basicAuth": False,
                    "isDefault": True,
                    "jsonData": {"httpMethod": "POST"},
                    "readOnly": False,
                }
            ],
        )

        result = self.grafana.datasource.list_datasources()
        self.assertEqual(result[0]["type"], "prometheus")
        self.assertEqual(len(result), 1)

    @requests_mock.Mocker()
    def test_get_datasource_proxy_data(self, m):
        # http://localhost:3000/api/datasources/proxy/1/api/v1/query_range?query=up%7binstance%3d%22localhost:9090%22%7d&start=1644164339&end=1644164639&step=60
        m.get(
            "http://localhost/api/datasources/proxy/1/api/v1/query_range",
            json={
                "status": "success",
                "data": {
                    "resultType": "matrix",
                    "result": [
                        {
                            "metric": {"__name__": "up", "instance": "localhost:9090", "job": "prometheus"},
                            "values": [
                                [1644164339, "1"],
                                [1644164399, "1"],
                                [1644164459, "1"],
                                [1644164519, "1"],
                                [1644164579, "1"],
                                [1644164639, "1"],
                            ],
                        }
                    ],
                },
            },
        )
        result = self.grafana.datasource.get_datasource_proxy_data(
            1,  # datasource_id
            query_type="query_range",
            expr='up{instance="localhost:9090"}',
            start=1644164339,
            end=1644164639,
            step=60,
        )
        self.assertEqual(result["status"], "success")
        self.assertEqual(result["data"]["result"][0]["metric"]["job"], "prometheus")
        self.assertEqual(len(result["data"]["result"][0]["values"]), 6)



import unittest

import requests_mock

from grafana_client import GrafanaApi
from grafana_client.client import (
    GrafanaBadInputError,
    GrafanaClientError,
    GrafanaServerError,
    GrafanaUnauthorizedError,
)


class AnnotationsTestCase(unittest.TestCase):
    def setUp(self):
        self.grafana = GrafanaApi(("admin", "admin"), host="localhost", url_path_prefix="", protocol="http")

    @requests_mock.Mocker()
    def test_annotations(self, m):
        m.get(
            "http://localhost/api/annotations?from=1563183710618&to=1563185212275"
            "&alertId=11&dashboardID=111&panelId=22&tags=tags-test&limit=1",
            json=[
                {
                    "id": 80,
                    "alertId": 11,
                    "alertName": "",
                    "dashboardId": 111,
                    "panelId": 22,
                    "userId": 0,
                    "newState": "",
                    "prevState": "",
                    "created": 1563280160455,
                    "updated": 1563280160455,
                    "time": 1563156456006,
                    "text": "Annotation Description",
                    "tags": ["tags-test"],
                    "login": "",
                    "email": "",
                    "avatarUrl": "",
                    "data": {},
                },
            ],
        )
        annotations = self.grafana.annotations.get_annotation(
            time_from=1563183710618,
            time_to=1563185212275,
            alert_id=11,
            dashboard_id=111,
            panel_id=22,
            tags=["tags-test"],
            limit=1,
        )
        self.assertEqual(annotations[0]["text"], "Annotation Description")
        self.assertEqual(annotations[0]["alertId"], 11)
        self.assertEqual(annotations[0]["dashboardId"], 111)
        self.assertEqual(annotations[0]["panelId"], 22)
        self.assertEqual(annotations[0]["tags"][0], "tags-test")

        self.assertEqual(len(annotations), 1)

    @requests_mock.Mocker()
    def test_annotations_with_out_param(self, m):
        m.get(
            "http://localhost/api/annotations",
            json=[
                {
                    "id": 80,
                    "alertId": 11,
                    "alertName": "",
                    "dashboardId": 111,
                    "panelId": 22,
                    "userId": 0,
                    "newState": "",
                    "prevState": "",
                    "created": 1563280160455,
                    "updated": 1563280160455,
                    "time": 1563156456006,
                    "text": "Annotation Description",
                    "tags": ["tags-test"],
                    "login": "",
                    "email": "",
                    "avatarUrl": "",
                    "data": {},
                },
            ],
        )
        annotations = self.grafana.annotations.get_annotation()
        self.assertEqual(len(annotations), 1)

    @requests_mock.Mocker()
    def test_delete_annotations_by_id(self, m):
        m.delete("http://localhost/api/annotations/99", json={"message": "Annotation deleted"})
        annotation = self.grafana.annotations.delete_annotations_by_id(annotations_id=99)
        self.assertEqual(annotation["message"], "Annotation deleted")

    @requests_mock.Mocker()
    def test_delete_annotations_by_id_could_not_find(self, m):
        m.delete(
            "http://localhost/api/annotations/None",
            json={"message": "Could not find annotation to update"},
            status_code=500,
        )
        with self.assertRaises(GrafanaServerError):
            response = self.grafana.annotations.delete_annotations_by_id(annotations_id=None)

    @requests_mock.Mocker()
    def test_delete_annotations_by_id_forbidden(self, m):
        m.delete("http://localhost/api/annotations/None", json={"message": "Forbidden"}, status_code=403)
        with self.assertRaises(GrafanaClientError):
            response = self.grafana.annotations.delete_annotations_by_id(annotations_id=None)

    @requests_mock.Mocker()
    def test_delete_annotations_by_id_unauthorized(self, m):
        m.delete("http://localhost/api/annotations/None", json={"message": "Unauthorized"}, status_code=401)
        with self.assertRaises(GrafanaUnauthorizedError):
            response = self.grafana.annotations.delete_annotations_by_id(annotations_id=None)

    @requests_mock.Mocker()
    def test_delete_annotations_by_id_bad_input(self, m):
        m.delete("http://localhost/api/annotations/None", json={"message": "Bad Input"}, status_code=400)
        with self.assertRaises(GrafanaBadInputError):
            response = self.grafana.annotations.delete_annotations_by_id(annotations_id=None)

    @requests_mock.Mocker()
    def test_add_annotation(self, m):
        m.post(
            "http://localhost/api/annotations",
            json={"endId": 80, "id": 79, "message": "Annotation added"},
        )
        annotation = self.grafana.annotations.add_annotation(
            time_from=1563183710618, time_to=1563185212275, tags=["tags-test"], text="Test"
        )
        self.assertEqual(annotation["endId"], 80)
        self.assertEqual(annotation["id"], 79)
        self.assertEqual(annotation["message"], "Annotation added")

    @requests_mock.Mocker()
    def test_update_annotation(self, m):
        m.put(
            "http://localhost/api/annotations/79",
            json={"endId": 80, "id": 79, "message": "Annotation updated"},
        )
        annotation = self.grafana.annotations.update_annotation(
            annotations_id=79, time_from=1563183710618, time_to=1563185212275, tags=["tags-test"], text="Test"
        )
        self.assertEqual(annotation["endId"], 80)
        self.assertEqual(annotation["id"], 79)
        self.assertEqual(annotation["message"], "Annotation updated")

    @requests_mock.Mocker()
    def test_partial_update_annotation(self, m):
        m.patch(
            "http://localhost/api/annotations/89",
            json={"message": "Annotation patched"},
        )
        annotation = self.grafana.annotations.partial_update_annotation(
            annotations_id=89, tags=["tag1", "tag2"], text="Test"
        )
        self.assertEqual(annotation["message"], "Annotation patched")

    @requests_mock.Mocker()
    def test_add_annotation_graphite(self, m):
        m.post(
            "http://localhost/api/annotations/graphite",
            json={"message": "Graphite annotation added", "id": 1},
        )
        annotation = self.grafana.annotations.add_annotation_graphite(
            what="Event - deploy", tags=["deploy", "production"], when=1467844481, data="Data"
        )

        self.assertEqual(annotation["id"], 1)
        self.assertEqual(annotation["message"], "Graphite annotation added")



import unittest

import requests_mock

from grafana_client import GrafanaApi
from grafana_client.client import (
    GrafanaBadInputError,
    GrafanaClientError,
    GrafanaServerError,
    GrafanaUnauthorizedError,
)


class HealthTestCase(unittest.TestCase):
    def setUp(self):
        self.grafana = GrafanaApi(("admin", "admin"), host="localhost", url_path_prefix="", protocol="http")

    @requests_mock.Mocker()
    def test_search_dashboards(self, m):
        m.get(
            "http://localhost/api/health",
            json=[{"commit": "6f8c1d9fe4", "database": "ok", "version": "7.5.11"}],
        )

        result = self.grafana.health.check()
        self.assertEqual(result[0]["database"], "ok")
        self.assertEqual(len(result), 1)



# Required for editable installs
# https://discuss.python.org/t/specification-of-editable-installation/1564/
from setuptools import setup
setup(
    use_scm_version={
        "local_scheme": "no-local-version",
        "version_scheme": "python-simplified-semver",
        "write_to": "grafana_client/version.py",
    },
)



import unittest

import requests_mock

from grafana_client import GrafanaApi
from grafana_client.client import GrafanaBadInputError


class FolderTestCase(unittest.TestCase):
    def setUp(self):
        self.grafana = GrafanaApi(("admin", "admin"), host="localhost", url_path_prefix="", protocol="http")

    @requests_mock.Mocker()
    def test_get_all_folders(self, m):
        m.get(
            "http://localhost/api/folders",
            json=[
                {
                    "id": 1,
                    "uid": "nErXDvCkzz",
                    "title": "Departmenet ABC",
                    "url": "/dashboards/f/nErXDvCkzz/department-abc",
                    "hasAcl": "false",
                    "canSave": "false",
                    "canEdit": "false",
                    "canAdmin": "false",
                    "createdBy": "admin",
                    "created": "2018-01-31T17:43:12+01:00",
                    "updatedBy": "admin",
                    "updated": "2018-01-31T17:43:12+01:00",
                    "version": 1,
                }
            ],
        )
        folders = self.grafana.folder.get_all_folders()
        self.assertEqual(folders[0]["id"], 1)
        self.assertEqual(len(folders), 1)

    @requests_mock.Mocker()
    def test_get_folder(self, m):
        m.get(
            "http://localhost/api/folders/nErXDvCkzzh",
            json={
                "id": 1,
                "uid": "nErXDvCkzzh",
                "title": "Departmenet ABC",
                "url": "/dashboards/f/nErXDvCkzz/department-abc",
                "hasAcl": "false",
                "canSave": "false",
                "canEdit": "false",
                "canAdmin": "false",
                "createdBy": "admin",
                "created": "2018-01-31T17:43:12+01:00",
                "updatedBy": "admin",
                "updated": "2018-01-31T17:43:12+01:00",
                "version": 1,
            },
        )
        folders = self.grafana.folder.get_folder(uid="nErXDvCkzzh")
        self.assertEqual(folders["uid"], "nErXDvCkzzh")

    @requests_mock.Mocker()
    def test_create_folder(self, m):
        m.post(
            "http://localhost/api/folders",
            json={
                "id": 1,
                "uid": "nErXDvCkzz",
                "title": "Departmenet ABC",
                "url": "/dashboards/f/nErXDvCkzz/department-abc",
                "hasAcl": "false",
                "canSave": "false",
                "canEdit": "false",
                "canAdmin": "false",
                "createdBy": "admin",
                "created": "2018-01-31T17:43:12+01:00",
                "updatedBy": "admin",
                "updated": "2018-01-31T17:43:12+01:00",
                "version": 1,
            },
        )
        folder = self.grafana.folder.create_folder(title="Departmenet ABC", uid="nErXDvCkzz")
        self.assertEqual(folder["uid"], "nErXDvCkzz")

    @requests_mock.Mocker()
    def test_create_folder_empty_uid(self, m):
        m.post("http://localhost/api/folders", json={"message": "Folder title cannot be empty"}, status_code=400)
        with self.assertRaises(GrafanaBadInputError):
            folder = self.grafana.folder.create_folder(title="Departmenet ABC")

    @requests_mock.Mocker()
    def test_update_folder(self, m):
        m.put(
            "http://localhost/api/folders/nErXDvCkzz",
            json={
                "id": 1,
                "uid": "nErXDvCkzz",
                "title": "Departmenet DEF",
                "url": "/dashboards/f/nErXDvCkzz/department-def",
                "hasAcl": "false",
                "canSave": "false",
                "canEdit": "false",
                "canAdmin": "false",
                "createdBy": "admin",
                "created": "2018-01-31T17:43:12+01:00",
                "updatedBy": "admin",
                "updated": "2018-01-31T17:43:12+01:00",
                "version": 1,
            },
        )
        folder = self.grafana.folder.update_folder(title="Departmenet DEF", uid="nErXDvCkzz", version=1, overwrite=True)
        self.assertEqual(folder["title"], "Departmenet DEF")

    @requests_mock.Mocker()
    def test_update_folder_some_param(self, m):
        m.put(
            "http://localhost/api/folders/nErXDvCkzz",
            json={
                "id": 1,
                "uid": "nErXDvCkzz",
                "title": "Departmenet DEF",
                "url": "/dashboards/f/nErXDvCkzz/department-def",
                "hasAcl": "false",
                "canSave": "false",
                "canEdit": "false",
                "canAdmin": "false",
                "createdBy": "admin",
                "created": "2018-01-31T17:43:12+01:00",
                "updatedBy": "admin",
                "updated": "2018-01-31T17:43:12+01:00",
                "version": 1,
            },
        )
        folder = self.grafana.folder.update_folder(title="Departmenet DEF", uid="nErXDvCkzz")
        self.assertEqual(folder["title"], "Departmenet DEF")

    @requests_mock.Mocker()
    def test_get_folder_by_id(self, m):
        m.get(
            "http://localhost/api/folders/id/1",
            json={
                "id": 1,
                "uid": "nErXDvCkzz",
                "title": "Departmenet ABC",
                "url": "/dashboards/f/nErXDvCkzz/department-abc",
                "hasAcl": "false",
                "canSave": "false",
                "canEdit": "false",
                "canAdmin": "false",
                "createdBy": "admin",
                "created": "2018-01-31T17:43:12+01:00",
                "updatedBy": "admin",
                "updated": "2018-01-31T17:43:12+01:00",
                "version": 1,
            },
        )
        folder = self.grafana.folder.get_folder_by_id(folder_id=1)
        self.assertEqual(folder["id"], 1)

    @requests_mock.Mocker()
    def test_get_folder_permissions(self, m):
        m.get(
            "http://localhost/api/folders/nErXDvCkzz/permissions",
            json=[
                {
                    "id": 1,
                    "folderId": -1,
                    "created": "2017-06-20T02:00:00+02:00",
                    "updated": "2017-06-20T02:00:00+02:00",
                    "userId": 0,
                    "userLogin": "",
                    "userEmail": "",
                    "teamId": 0,
                    "team": "",
                    "role": "Viewer",
                    "permission": 1,
                    "permissionName": "View",
                    "uid": "nErXDvCkzz",
                    "title": "",
                    "slug": "",
                    "isFolder": "false",
                    "url": "",
                },
                {
                    "id": 2,
                    "dashboardId": -1,
                    "created": "2017-06-20T02:00:00+02:00",
                    "updated": "2017-06-20T02:00:00+02:00",
                    "userId": 0,
                    "userLogin": "",
                    "userEmail": "",
                    "teamId": 0,
                    "team": "",
                    "role": "Editor",
                    "permission": 2,
                    "permissionName": "Edit",
                    "uid": "",
                    "title": "",
                    "slug": "",
                    "isFolder": "false",
                    "url": "",
                },
            ],
        )
        folder_permissions = self.grafana.folder.get_folder_permissions(uid="nErXDvCkzz")
        self.assertEqual(folder_permissions[0]["permissionName"], "View")

    @requests_mock.Mocker()
    def test_update_folder_permissions(self, m):
        m.post("http://localhost/api/folders/nErXDvCkzz/permissions", json={"message": "Folder permissions updated"})
        folder = self.grafana.folder.update_folder_permissions(
            uid="nErXDvCkzz",
            items=[
                {"role": "Viewer", "permission": 1},
                {"role": "Editor", "permission": 2},
                {"teamId": 1, "permission": 1},
                {"userId": 11, "permission": 4},
            ],
        )
        self.assertEqual(folder["message"], "Folder permissions updated")

    @requests_mock.Mocker()
    def test_delete_folder(self, m):
        m.delete("http://localhost/api/folders/nErXDvCkzz", json={"message": "Folder deleted"})
        folder = self.grafana.folder.delete_folder(uid="nErXDvCkzz")
        self.assertEqual(folder["message"], "Folder deleted")



from .base import Base


class Dashboard(Base):
    def __init__(self, client):
        super(Dashboard, self).__init__(client)
        self.client = client

    def get_dashboard(self, dashboard_uid):
        """

        :param dashboard_uid:
        :return:
        """
        get_dashboard_path = "/dashboards/uid/%s" % dashboard_uid
        r = self.client.GET(get_dashboard_path)
        return r

    def update_dashboard(self, dashboard):
        """

        :param dashboard:
        :return:
        """

        # When the "folderId" is not available within the dashboard payload,
        # populate it from the nested "meta" object, if given.
        if "folderId" not in dashboard:
            if "meta" in dashboard and "folderId" in dashboard["meta"]:
                dashboard = dashboard.copy()
                dashboard["folderId"] = dashboard["meta"]["folderId"]

        put_dashboard_path = "/dashboards/db"
        r = self.client.POST(put_dashboard_path, json=dashboard)
        return r

    def delete_dashboard(self, dashboard_uid):
        """

        :param dashboard_uid:
        :return:
        """
        delete_dashboard_path = "/dashboards/uid/%s" % dashboard_uid
        r = self.client.DELETE(delete_dashboard_path)
        return r

    def get_home_dashboard(self):
        """

        :return:
        """
        get_home_dashboard_path = "/dashboards/home"
        r = self.client.GET(get_home_dashboard_path)
        return r

    def get_dashboards_tags(self):
        """

        :return:
        """
        get_dashboards_tags_path = "/dashboards/tags"
        r = self.client.GET(get_dashboards_tags_path)
        return r

    def get_dashboard_permissions(self, dashboard_id):
        """

        :param dashboard_id:
        :return:
        """
        get_dashboard_permissions_path = "/dashboards/id/%s/permissions" % dashboard_id
        r = self.client.GET(get_dashboard_permissions_path)
        return r

    def update_dashboard_permissions(self, dashboard_id, items):
        """

        :param dashboard_id:
        :param items:
        :return:
        """
        update_dashboard_permissions_path = "/dashboards/id/%s/permissions" % dashboard_id
        r = self.client.POST(update_dashboard_permissions_path, json=items)
        return r



from .base import Base


class Users(Base):
    def __init__(self, client):
        super(Users, self).__init__(client)
        self.client = client

    def search_users(self, query=None, page=None, perpage=None):
        """

        :return:
        """
        list_of_users = []
        users_on_page = None
        show_users_path = "/users"
        params = []

        if query:
            params.append("query=%s" % query)

        if page:
            iterate = False
            params.append("page=%s" % page)
        else:
            iterate = True
            params.append("page=%s")
            page = 1

        if perpage:
            params.append("perpage=%s" % perpage)

        show_users_path += "?"
        show_users_path += "&".join(params)

        if iterate:
            while True:
                users_on_page = self.client.GET(show_users_path % page)
                if not users_on_page:
                    break
                list_of_users += users_on_page
                page += 1
        else:
            users_on_page = self.client.GET(show_users_path)
            list_of_users += users_on_page

        return list_of_users

    def get_user(self, user_id):
        """

        :param user_id:
        :return:
        """
        get_user_path = "/users/%s" % user_id
        r = self.client.GET(get_user_path)
        return r

    def find_user(self, login_or_email):
        """

        :param login_or_email:
        :return:
        """
        search_user_path = "/users/lookup?loginOrEmail=%s" % login_or_email
        r = self.client.GET(search_user_path)
        return r

    def update_user(self, user_id, user):
        """

        :param user_id:
        :param user:
        :return:
        """
        update_user_path = "/users/%s" % user_id
        r = self.client.PUT(update_user_path, json=user)
        return r

    def get_user_organisations(self, user_id):
        """

        :param user_id:
        :return:
        """
        get_user_organisations_path = "/users/%s/orgs" % user_id
        r = self.client.GET(get_user_organisations_path)
        return r


class User(Base):
    def __init__(self, client):
        super(User, self).__init__(client)
        self.client = client
        self.path = "/user"

    def get_actual_user(self):
        """

        :return:
        """
        get_actual_user_path = "/user"
        r = self.client.GET(get_actual_user_path)
        return r

    def change_actual_user_password(self, old_password, new_password):
        """

        :param old_password:
        :param new_password:
        :return:
        """
        change_actual_user_password_path = "/user/password"
        change_actual_user_password_json = {
            "oldPassword": old_password,
            "newPassword": new_password,
            "confirmNew": new_password,
        }
        r = self.client.PUT(change_actual_user_password_path, json=change_actual_user_password_json)
        return r

    def switch_user_organisation(self, user_id, organisation_id):
        """

        :param user_id:
        :param organisation_id:
        :return:
        """
        switch_user_organisation_path = "/users/%s/using/%s" % (
            user_id,
            organisation_id,
        )
        r = self.client.POST(switch_user_organisation_path)
        return r

    def switch_actual_user_organisation(self, organisation_id):
        """

        :param organisation_id:
        :return:
        """
        switch_actual_user_organisation_path = "/user/using/%s" % organisation_id
        r = self.client.POST(switch_actual_user_organisation_path)
        return r

    def get_actual_user_organisations(self):
        """

        :return:
        """
        get_actual_user_organisations_path = "/user/orgs"
        r = self.client.GET(get_actual_user_organisations_path)
        return r

    def star_actual_user_dashboard(self, dashboard_id):
        """

        :param dashboard_id:
        :return:
        """
        star_dashboard = "/user/stars/dashboard/%s" % dashboard_id
        r = self.client.POST(star_dashboard)
        return r

    def unstar_actual_user_dashboard(self, dashboard_id):
        """

        :param dashboard_id:
        :return:
        """
        unstar_dashboard = "/user/stars/dashboard/%s" % dashboard_id
        r = self.client.DELETE(unstar_dashboard)
        return r
